==> steam-trader-0.4.0.tar.gz: steam-trader-0.4.0/steam_trader/api/_buy.py <==
import logging
from dataclasses import dataclass
from collections.abc import Sequence
from typing import TYPE_CHECKING, Optional, Union

from .. import exceptions
from ._misc import MultiBuyOrder
from ._base import TraderClientObject

if TYPE_CHECKING:
    from ._client import Client
    from ._client_async import ClientAsync

@dataclass(slots=True)
class BuyResult(TraderClientObject):
    """Класс, представляющий результат покупки.

    Attributes:
        success (:obj:`bool`): Результат запроса.
        id (:obj:`int`): Уникальный ID покупки.
        gid (:obj:`int`): ID группы предметов.
        itemid (:obj:`int`): ID купленного предмета.
        price (:obj:`float`): Цена, за которую был куплен предмет с учётом скидки.
        new_price (:obj:`float`): Новая цена лучшего предложения о продаже для варианта покупки Commodity,
            если у группы предметов ещё имеются предложения о продаже. Для остальных вариантов покупки будет 0
        discount (:obj:`float`): Размер скидки в процентах, за которую был куплен предмет.
        client (Union[:class:`steam_trader.api.api.Client`, :class:`steam_trader.api.api.ClientAsync`, :obj:`None`]):
            Клиент Steam Trader.
    """

    success: bool
    id: int
    gid: int
    itemid: int
    price: float
    new_price: float
    discount: float
    client: Union['Client', 'ClientAsync', None]

    @classmethod
    def de_json(
            cls: dataclass,
            data: dict,
            client: Union['Client', 'ClientAsync', None] = None
    ) -> 'BuyResult':

        if not data['success']:
            match data['code']:
                case 400:
                    raise exceptions.BadRequestError('Неправильный запрос.')
                case 401:
                    raise exceptions.Unauthorized('Неправильный api-токен.')
                case 429:
                    raise exceptions.TooManyRequests('Вы отправили слишком много запросов.')
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 4:
                    raise exceptions.NoLongerExists('Предложение больше недействительно.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        data = super(BuyResult, cls).de_json(data)

        return cls(client=client, **data)

@dataclass(slots=True)
class BuyOrderResult(TraderClientObject):
    """Класс, представляющий результат запроса на покупку.

    Attributes:
        success (:obj:`bool`): Результат запроса.
        executed (:obj:`int`): Количество исполненных заявок.
        placed (:obj:`int`): Количество размещённых на маркет заявок.
        client (Union[:class:`steam_trader.api.api.Client`, :class:`steam_trader.api.api.ClientAsync`, :obj:`None`]):
            Клиент Steam Trader.
    """

    success: bool
    executed: int
    placed: int
    client: Union['Client', 'ClientAsync', None]

    @classmethod
    def de_json(
            cls: dataclass,
            data: dict,
            client: Union['Client', 'ClientAsync', None] = None
    ) -> 'BuyOrderResult':

        del data['orders']  # Конфликт с steam_trader.api.api.BuyOrder

        if not data['success']:
            match data['code']:
                case 400:
                    raise exceptions.BadRequestError('Неправильный запрос.')
                case 401:
                    raise exceptions.Unauthorized('Неправильный api-токен.')
                case 429:
                    raise exceptions.TooManyRequests('Вы отправили слишком много запросов.')
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 2:
                    raise exceptions.UnknownItem('Неизвестный предмет.')
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 4:
                    raise exceptions.NoLongerExists('Предложение больше недействительно.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        data = super(BuyOrderResult, cls).de_json(data)

        return cls(client=client, **data)

@dataclass(slots=True)
class MultiBuyResult(TraderClientObject):
    """Класс, представляющий результат мульти-покупки.

    Attributes:
        success (:obj:`bool`): Результат запроса.
        balance (:obj:`float`, optional): Баланс после покупки предметов. Указывается если success = True
        spent (:obj:`float`, optional): Сумма потраченных средств на покупку предметов. Указывается если success = True
        orders (Sequence[:class:`steam_trader.api.api.MultiBuyOrder`], optional):
            Последовательность купленных предметов. Указывается если success = True
        left (:obj:`int`): Сколько предметов по этой цене осталось. Если операция прошла успешно, всегда равен 0.
        client (Union[:class:`steam_trader.api.api.Client`, :class:`steam_trader.api.api.ClientAsync`, :obj:`None`]):
            Клиент Steam Trader.

    Changes:
        0.2.3: Теперь, если во время операции закончиться баланс, вместо ошибки,
            в датаклассе будет указано кол-во оставшихся предметов по данной цене.
    """

    success: bool
    client: Union['Client', 'ClientAsync', None]
    balance: Optional[float] = None
    spent: Optional[float] = None
    orders: Optional[Sequence['MultiBuyOrder']] = None
    left: int = 0

    @classmethod
    def de_json(
            cls: dataclass,
            data: dict,
            client: Union['Client', 'ClientAsync', None] = None
    ) -> 'MultiBuyResult':

        if not data['success']:
            match data['code']:
                case 400:
                    raise exceptions.BadRequestError('Неправильный запрос.')
                case 401:
                    raise exceptions.Unauthorized('Неправильный api-токен.')
                case 429:
                    raise exceptions.TooManyRequests('Вы отправили слишком много запросов.')
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 2:
                    logging.warning(data['error'])
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        for i, offer in enumerate(data['orders']):
            data['orders'][i] = MultiBuyOrder.de_json(offer)

        data = super(MultiBuyResult, cls).de_json(data)

        return cls(client=client, **data)

==> steam-trader-1.0.1.tar.gz: steam-trader-1.0.1/steam_trader/api/_buy.py <==
import logging
from dataclasses import dataclass
from collections.abc import Sequence
from typing import Optional, Any

from .. import exceptions
from ._misc import MultiBuyOrder
from ._base import TraderClientObject

@dataclass(slots=True)
class BuyResult(TraderClientObject):
    """Класс, представляющий результат покупки.

    Attributes:
        success (bool): Результат запроса.
        id (int): Уникальный ID покупки.
        gid (int): ID группы предметов.
        itemid (int): ID купленного предмета.
        price (float): Цена, за которую был куплен предмет с учётом скидки.
        new_price (float): Новая цена лучшего предложения о продаже для варианта покупки Commodity,
            если у группы предметов ещё имеются предложения о продаже. Для остальных вариантов покупки будет 0
        discount (float): Размер скидки в процентах, за которую был куплен предмет.
    """

    success: bool
    id: int
    gid: int
    itemid: int
    price: float
    new_price: float
    discount: float

    @classmethod
    def de_json(
            cls,
            data: dict[str, Any]
    ) -> 'BuyResult':

        if not data['success']:
            match data['code']:
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 4:
                    raise exceptions.NoLongerExists('Предложение больше недействительно.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        data = super(BuyResult, cls)._de_json(data)

        return cls(**data)

@dataclass(slots=True)
class BuyOrderResult(TraderClientObject):
    """Класс, представляющий результат запроса на покупку.

    Attributes:
        success (bool): Результат запроса.
        executed (int): Количество исполненных заявок.
        placed (int): Количество размещённых на маркет заявок.
    """

    success: bool
    executed: int
    placed: int

    @classmethod
    def de_json(
            cls,
            data: dict[str, Any]
    ) -> 'BuyOrderResult':

        del data['orders']  # Конфликт с steam_trader.api.api.BuyOrder

        if not data['success']:
            match data['code']:
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 2:
                    raise exceptions.UnknownItem('Неизвестный предмет.')
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 4:
                    raise exceptions.NoLongerExists('Предложение больше недействительно.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        data = super(BuyOrderResult, cls)._de_json(data)

        return cls(**data)

@dataclass(slots=True)
class MultiBuyResult(TraderClientObject):
    """Класс, представляющий результат мульти-покупки.

    Attributes:
        success (bool): Результат запроса.
        balance (float, optional): Баланс после покупки предметов. Указывается если success = True
        spent (float, optional): Сумма потраченных средств на покупку предметов. Указывается если success = True
        orders (Sequence[steam_trader.api.api.MultiBuyOrder], optional):
            Последовательность купленных предметов. Указывается если success = True
        left (int): Сколько предметов по этой цене осталось. Если операция прошла успешно, всегда равен 0.

    Changes:
        0.2.3: Теперь, если во время операции закончиться баланс, вместо ошибки,
            в датаклассе будет указано кол-во оставшихся предметов по данной цене.
    """

    success: bool
    balance: Optional[float] = None
    spent: Optional[float] = None
    orders: Optional[Sequence[MultiBuyOrder]] = None
    left: int = 0

    @classmethod
    def de_json(
            cls,
            data: dict[str, Any]
    ) -> 'MultiBuyResult':

        if not data['success']:
            match data['code']:
                case 1:
                    raise exceptions.InternalError('При создании запроса произошла неизвестная ошибка.')
                case 2:
                    logging.warning(data['error'])
                case 3:
                    raise exceptions.NoTradeLink('Отсутствует сслыка для обмена.')
                case 5:
                    raise exceptions.NotEnoughMoney('Недостаточно средств.')

        for i, offer in enumerate(data['orders']):
            data['orders'][i] = MultiBuyOrder.de_json(offer)

        data = super(MultiBuyResult, cls)._de_json(data)

        return cls(**data)
